@@ -131,25 +131,25 @@ gmi_reset (GstMediaInfo *info)
   /* clear out some stuff */
   if (priv->format)
   {
-    g_warning ("unreffing priv->format, error ?\n");
+    GMI_DEBUG ("unreffing priv->format, error before this ?\n");
     gst_caps_unref (priv->format);
     priv->format = NULL;
   }
   if (priv->metadata)
   {
-    g_warning ("unreffing priv->metadata, error ?\n");
+    GMI_DEBUG ("unreffing priv->metadata, error before this ?\n");
     gst_caps_unref (priv->metadata);
     priv->metadata = NULL;
   }
   if (priv->stream)
   {
-    g_warning ("freeing priv->stream, error ?\n");
+    GMI_DEBUG ("freeing priv->stream, error before this ?\n");
     g_free (priv->stream);
     priv->stream = NULL;
   }
   if (priv->location)
   {
-    g_warning ("freeing priv->location, error ?\n");
+    GMI_DEBUG ("freeing priv->location, error before this ?\n");
     g_free (priv->location);
     priv->location = NULL;
   }
@@ -180,10 +180,11 @@ gmi_seek_to_track (GstMediaInfo *info, long track)
 			      GST_SEEK_FLAG_FLUSH,
 			      track);
   res = gst_pad_send_event (info->priv->decoder_pad, event);
-  g_assert (res);
   if (!res)
   {
-    g_warning ("seek to logical track failed");
+    g_warning ("seek to logical track on pad %s:%s failed of element %s",
+               GST_DEBUG_PAD_NAME(info->priv->decoder_pad),
+               gst_element_get_factory((gst_pad_get_parent(info->priv->decoder_pad)))->details->longname);
     return FALSE;
   }
   /* clear structs because of the seek */
@@ -215,16 +216,22 @@ gmi_get_decoder (GstMediaInfo *info, const char *mime)
   {
     GMI_DEBUG("DEBUG: no decoder in table, inserting one\n");
     /* FIXME: please figure out proper mp3 mimetypes */
-    if (strcmp (mime, "application/x-ogg") == 0)
+    if ((strcmp (mime, "application/x-ogg") == 0) ||
+        (strcmp (mime, "application/ogg") == 0))
       factory = g_strdup ("vorbisfile");
-    else if (strcmp (mime, "audio/mpeg") == 0)
-      factory = g_strdup ("mad");
-    else if (strcmp (mime, "audio/x-mp3") == 0)
-      factory = g_strdup ("mad");
-    else if (strcmp (mime, "audio/mp3") == 0)
+    else if ((strcmp (mime, "audio/mpeg") == 0) ||
+             (strcmp (mime, "audio/x-mp3") == 0) ||
+             (strcmp (mime, "audio/mp3") == 0))
       factory = g_strdup ("mad");
+    else if (strcmp (mime, "application/x-flac") == 0)
+      factory = g_strdup ("flacdec");
     else if (strcmp (mime, "audio/x-wav") == 0)
       factory = g_strdup ("wavparse");
+    else if (strcmp (mime, "audio/x-mod") == 0 ||
+	     strcmp (mime, "audio/x-s3m") == 0 ||
+             strcmp (mime, "audio/x-xm") == 0 ||
+	     strcmp (mime, "audio/x-it") == 0)
+      factory = g_strdup ("modplug");
 
     if (factory == NULL)
       return NULL;
@@ -292,7 +299,9 @@ gmip_find_type_pre (GstMediaInfoPriv *priv)
   /* clear vars that need clearing */
   if (priv->type)
   {
-    gst_caps_unref (priv->type);
+    /* we don't need to unref, this is done inside gsttypefind.c
+       gst_caps_unref (priv->type);
+     */
     priv->type = NULL;
   }
 
@@ -393,7 +402,7 @@ gmip_find_stream_post (GstMediaInfoPriv *priv)
     definition = gst_format_get_details (*formats);
     GMI_DEBUG("trying to figure out length for format %s\n", definition->nick);
 
-    res = gst_pad_query (priv->decoder_pad, GST_PAD_QUERY_TOTAL,
+    res = gst_pad_query (priv->decoder_pad, GST_QUERY_TOTAL,
                          &format, &value);
 
     if (res)
@@ -428,7 +437,7 @@ gmip_find_stream_post (GstMediaInfoPriv *priv)
   /* now get number of bytes from the sink pad to get the bitrate */
   format = GST_FORMAT_BYTES;
   g_assert (GST_IS_PAD (priv->source_pad));
-  res = gst_pad_query (priv->source_pad, GST_PAD_QUERY_TOTAL,
+  res = gst_pad_query (priv->source_pad, GST_QUERY_TOTAL,
                        &format, &value);
   if (!res) g_warning ("Failed to query on sink pad !");
   bytes = value;
@@ -543,7 +552,7 @@ gmip_find_track_streaminfo_post (GstMediaInfoPriv *priv)
     gint64 value_start, value_end;
     gboolean res;
 
-    res = gst_pad_query (priv->decoder_pad, GST_PAD_QUERY_POSITION,
+    res = gst_pad_query (priv->decoder_pad, GST_QUERY_POSITION,
 		         &track_format, &value_start);
     if (res)
     {
